# Changes

## 2022.11.3

* Made the liitos.templates package an explicit member (YAGNI)

## 2022.11.2

* Added meta data parsing to verifier
* Added verbosity flag

## 2022.10.18

* Added YAML format readers for approvals and changes

## 2022.9.18

* Added command line verification script
* Added documentation
* Added PyYAML dependency

## 2022.8.1

* Initial release on PyPI
